make_null_formula: make_null_formula

Description Usage Arguments

View source: R/mediations.R

Description

make_null_formula

Usage

1
make_null_formula(model, name, random)

Arguments

model

A specific model from a permediatrMod object.

name

The variable name to be excluded from the model.

random

Whether the variable name is also included in the random effects part of the model.


jflournoy/permediatr documentation built on Dec. 10, 2019, 11:34 a.m.