make_null_formula
1 | make_null_formula(model, name, random)
|
model |
A specific model from a permediatrMod object. |
name |
The variable name to be excluded from the model. |
random |
Whether the variable name is also included in the random effects part of the model. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.